@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from lib.decorator import route
 from lib.decorator import get
-from app.common import errors
 
 
 @get('/', apply='json', skip='jinja2')
